@@ -5,6 +5,7 @@
 #'
 #' @export
 #' @name index_template
+#' @param conn an Elasticsearch connection object, see [connect()]
 #' @param name (character) The name of the template
 #' @param body (character/list) The template definition
 #' @param create (logical) Whether the index template should only be added 
@@ -25,6 +26,8 @@
 #' <https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
 #'
 #' @examples \dontrun{
+#' (x <- connect())
+#' 
 #' body <- '{
 #'   "template": "te*",
 #'   "settings": {
@@ -47,86 +50,89 @@
 #'     }
 #'   }
 #' }'
-#' index_template_put("template_1", body = body)
+#' index_template_put(x, "template_1", body = body)
 #' 
 #' # get templates
-#' index_template_get()
-#' index_template_get("template_1")
-#' index_template_get(c("template_1", "template_2"))
-#' index_template_get("template_*")
+#' index_template_get(x)
+#' index_template_get(x, "template_1")
+#' index_template_get(x, c("template_1", "template_2"))
+#' index_template_get(x, "template_*")
 #' ## filter path
-#' index_template_get("template_1", filter_path = "*.template")
+#' index_template_get(x, "template_1", filter_path = "*.template")
 #' 
 #' # template exists
-#' index_template_exists("template_1")
-#' index_template_exists("foobar")
+#' index_template_exists(x, "template_1")
+#' index_template_exists(x, "foobar")
 #' 
 #' # delete a template
-#' index_template_delete("template_1")
-#' index_template_exists("template_1")
+#' index_template_delete(x, "template_1")
+#' index_template_exists(x, "template_1")
 #' }
 index_template_put <- function(
-  name, body = NULL, create = NULL, flat_settings = NULL, master_timeout = NULL,
-  order = NULL, timeout = NULL, ...) {
+  conn, name, body = NULL, create = NULL, flat_settings = NULL, 
+  master_timeout = NULL, order = NULL, timeout = NULL, ...) {
   
-  url <- make_url(es_get_auth())
+  is_conn(conn)
+  url <- conn$make_url()
   url <- file.path(url, "_template", esc(name))
   args <- ec(list(create = create, flat_settings = flat_settings,
                   master_timeout = master_timeout,
                   order = order, timeout = timeout))
-  indtemp_PUT(url, args, body, ...)
+  indtemp_PUT(conn, url, args, body, ...)
 }
 
 #' @export
 #' @rdname index_template
-index_template_get <- function(name = NULL, filter_path = NULL, ...) {
-  url <- file.path(make_url(es_get_auth()), "_template")
+index_template_get <- function(conn, name = NULL, filter_path = NULL, ...) {
+  is_conn(conn)
+  url <- file.path(conn$make_url(), "_template")
   if (!is.null(name)) {
     if (length(name) > 1) name <- paste0(esc(name), collapse = ",")
     url <- file.path(url, name)
   }
   args <- ec(list(filter_path = filter_path))
-  indtemp_GET(url, args, ...)
+  indtemp_GET(conn, url, args, ...)
 }
 
 #' @export
 #' @rdname index_template
-index_template_exists <- function(name, ...) {
-  url <- file.path(make_url(es_get_auth()), "_template", name)
-  indtemp_HEAD(url, ...)
+index_template_exists <- function(conn, name, ...) {
+  is_conn(conn)
+  url <- file.path(conn$make_url(), "_template", name)
+  indtemp_HEAD(conn, url, ...)
 }
 
 #' @export
 #' @rdname index_template
-index_template_delete <- function(name, ...) {
-  url <- file.path(make_url(es_get_auth()), "_template", name)
-  indtemp_DELETE(url, ...)
+index_template_delete <- function(conn, name, ...) {
+  is_conn(conn)
+  url <- file.path(conn$make_url(), "_template", name)
+  indtemp_DELETE(conn, url, ...)
 }
 
 
 # helpers ------------
-indtemp_PUT <- function(url, args, body = list(), ...) {
+indtemp_PUT <- function(conn, url, args, body = list(), ...) {
   body <- check_inputs(body)
-  tt <- PUT(url, body = body, query = args, encode = 'json', 
-            make_up(), content_type_json(), es_env$headers, ...)
-  geterror(tt)
-  if (tt$status_code == 200) TRUE else FALSE
+  cli <- conn$make_conn(url, json_type(), ...)
+  tt <- cli$put(body = body, query = args, encode = 'json')
+  geterror(conn, tt)
+  tt$status_code == 200
 }
 
-indtemp_GET <- function(url, args, ...) {
-  tt <- GET(url, query = args, make_up(), 
-            content_type_json(), es_env$headers, ...)
-  geterror(tt)
-  jsonlite::fromJSON(cont_utf8(tt), FALSE)
+indtemp_GET <- function(conn, url, args, ...) {
+  tt <- conn$make_conn(url, json_type(), ...)$get(query = args)
+  geterror(conn, tt)
+  jsonlite::fromJSON(tt$parse("UTF-8"), FALSE)
 }
 
-indtemp_HEAD <- function(url, ...) {
-  tt <- HEAD(url, make_up(), content_type_json(), es_env$headers, ...)
-  if (tt$status_code == 200) TRUE else FALSE
+indtemp_HEAD <- function(conn, url, ...) {
+  tt <- conn$make_conn(url, json_type(), ...)$head()
+  tt$status_code == 200
 }
 
-indtemp_DELETE <- function(url, ...) {
-  tt <- DELETE(url, make_up(), es_env$headers, ...)
-  geterror(tt)
-  if (tt$status_code == 200) TRUE else FALSE
+indtemp_DELETE <- function(conn, url, ...) {
+  tt <- conn$make_conn(url, json_type(), ...)$delete()
+  geterror(conn, tt)
+  tt$status_code == 200
 }
