@@ -2,11 +2,12 @@
 #'
 #' @export
 #' @name Search_template
+#' @param conn an Elasticsearch connection object, see [connect()]
 #' @param template (character) a template name
 #' @param body Query, either a list or json.
 #' @param raw (logical) If `FALSE` (default), data is parsed to list.
 #' If `TRUE`, then raw JSON returned
-#' @param ... Curl args passed on to [httr::POST()]
+#' @param ... Curl args passed on to [crul::verb-POST]
 #'
 #' @seealso [Search()], [Search_uri()]
 #'
@@ -33,8 +34,11 @@
 #' <https://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html>
 #'
 #' @examples \dontrun{
-#' if (!index_exists("iris")) {
-#'   invisible(docs_bulk(iris, "iris"))
+#' # connection setup
+#' (x <- connect())
+#' 
+#' if (!index_exists(x, "iris")) {
+#'   invisible(docs_bulk(x, iris, "iris"))
 #' }
 #'
 #' body1 <- '{
@@ -48,7 +52,7 @@
 #'     "my_size" : 3
 #'   }
 #' }'
-#' Search_template(body = body1)
+#' Search_template(x, body = body1)
 #'
 #' body2 <- '{
 #'  "inline": {
@@ -62,34 +66,50 @@
 #'    "query_string": "versicolor"
 #'  }
 #' }'
-#' Search_template(body = body2)
+#' Search_template(x, body = body2)
 #'
 #' # pass in a list
 #' mylist <- list(
 #'   inline = list(query = list(match = list(`{{my_field}}` = "{{my_value}}"))),
 #'   params = list(my_field = "Species", my_value = "setosa", my_size = 3L)
 #' )
-#' Search_template(body = mylist)
+#' Search_template(x, body = mylist)
 #'
 #' ## Validating templates w/ Search_template_render()
-#' Search_template_render(body = body1)
-#' Search_template_render(body = body2)
+#' Search_template_render(x, body = body1)
+#' Search_template_render(x, body = body2)
 #'
 #' ## pre-registered templates
 #' ### register a template
-#' body3 <- '{
-#'   "template": {
-#'      "query": {
-#'          "match": {
-#'              "Species": "{{query_string}}"
-#'          }
+#' if (x$es_ver() <= 520) {
+#'   body3 <- '{
+#'     "template": {
+#'        "query": {
+#'            "match": {
+#'                "Species": "{{query_string}}"
+#'            }
+#'        }
 #'      }
-#'    }
-#' }'
-#' Search_template_register('foobar', body = body3)
-#'
+#'   }'
+#'   Search_template_register(x, 'foobar', body = body3)
+#' } else {
+#'   body3 <- '{
+#'    "script": {
+#'      "lang": "mustache",
+#'        "source": {
+#'          "query": {
+#'            "match": {
+#'              "Species": "{{query_string}}"
+#'            }
+#'          }
+#'        }
+#'      }
+#'   }'
+#'   Search_template_register(x, 'foobar', body = body3)
+#' }
+#' 
 #' ### get template
-#' Search_template_get('foobar')
+#' Search_template_get(x, 'foobar')
 #'
 #' ### use the template
 #' body4 <- '{
@@ -98,66 +118,86 @@
 #'       "query_string": "setosa"
 #'   }
 #' }'
-#' Search_template(body = body4)
+#' Search_template(x, body = body4)
 #'
 #' ### delete the template
-#' Search_template_delete('foobar')
+#' Search_template_delete(x, 'foobar')
 #' }
-Search_template <- function(body = list(), raw = FALSE, ...) {
+Search_template <- function(conn, body = list(), raw = FALSE, ...) {
+  is_conn(conn)
   # search template render added in Elasticsearch v1.1, stop if version pre that
-  if (es_ver() < 110) {
+  if (conn$es_ver() < 110) {
     stop("search template not available in this ES version", call. = FALSE)
   }
-  search_POST("_search/template", args = list(), body = body, raw = raw, 
+  search_POST(conn, "_search/template", args = list(), body = body, raw = raw, 
               asdf = FALSE, stream_opts = list(), ...)
 }
 
 #' @export
 #' @rdname Search_template
-Search_template_register <- function(template, body = list(), raw = FALSE, 
+Search_template_register <- function(conn, template, body = list(), raw = FALSE, 
                                      ...) {
+  is_conn(conn)
   # search template render added in Elasticsearch v1.1, stop if version pre that
-  if (es_ver() < 110) {
+  if (conn$es_ver() < 110) {
     stop("search template not available in this ES version", call. = FALSE)
   }
-  search_POST(
-    paste0("_search/template/", template),
-    args = list(), body = body, raw = raw, asdf = FALSE, 
+  # path for registering a template changed in Elasticsearch v5.2
+  if (conn$es_ver() <= 560) {
+    path <- file.path("_search/template", template)
+  } else {
+    path <- file.path("_scripts", template)
+  }
+  search_POST(conn, 
+    path = path, args = list(), body = body, raw = raw, asdf = FALSE, 
     stream_opts = list(), ...
   )
 }
 
 #' @export
 #' @rdname Search_template
-Search_template_get <- function(template, ...) {
+Search_template_get <- function(conn, template, ...) {
+  is_conn(conn)
   # search template render added in Elasticsearch v1.1, stop if version pre that
-  if (es_ver() < 110) {
+  if (conn$es_ver() < 110) {
     stop("search template not available in this ES version", call. = FALSE)
   }
-  url <- make_url(es_get_auth())
-  url <- paste0(url, "/_search/template/", template)
-  es_GET_(url, ...)
+  url <- conn$make_url()
+  # path for fetching a template changed in Elasticsearch v5.2
+  if (conn$es_ver() <= 520) {
+    url <- file.path(url, "_search/template", template)
+  } else {
+    url <- file.path(url, "_scripts", template)
+  }
+  es_GET_(conn, url, ...)
 }
 
 #' @export
 #' @rdname Search_template
-Search_template_delete <- function(template, ...) {
+Search_template_delete <- function(conn, template, ...) {
+  is_conn(conn)
   # search template render added in Elasticsearch v1.1, stop if version pre that
-  if (es_ver() < 110) {
+  if (conn$es_ver() < 110) {
     stop("search template not available in this ES version", call. = FALSE)
   }
-  url <- make_url(es_get_auth())
-  url <- paste0(url, "/_search/template/", template)
-  es_DELETE(url, ...)
+  url <- conn$make_url()
+  # path for deleting a template changed in Elasticsearch v5.2
+  if (conn$es_ver() <= 520) {
+    url <- file.path(url, "_search/template", template)
+  } else {
+    url <- file.path(url, "_scripts", template)
+  }
+  es_DELETE(conn, url, ...)
 }
 
 #' @export
 #' @rdname Search_template
-Search_template_render <- function(body = list(), raw = FALSE, ...) {
+Search_template_render <- function(conn, body = list(), raw = FALSE, ...) {
+  is_conn(conn)
   # search template render added in Elasticsearch v2.0, stop if version pre that
-  if (es_ver() < 200) {
+  if (conn$es_ver() < 200) {
     stop("render template not available in this ES version", call. = FALSE)
   }
-  search_POST("_render/template", args = list(), body = body, raw = raw, 
+  search_POST(conn, "_render/template", args = list(), body = body, raw = raw, 
               asdf = FALSE, stream_opts = list(), ...)
 }
