@@ -1,17 +1,13 @@
 context("mlt")
 
-invisible(tryCatch(elastic::connect(), error = function(e) e))
+invisible(connect())
 
 ## create plos index first -----------------------------------
-tryconnect = tryCatch(elastic::connect(), error = function(e) e)
-if (!is(tryconnect, "simpleError")) {
-  invisible(tryCatch(index_delete(index = "plos", verbose = FALSE), error = function(e) e))
-  plosdat <- system.file("examples", "plos_data.json", package = "elastic")
-  invisible(docs_bulk(plosdat))
-}
+invisible(tryCatch(index_delete(index = "plos", verbose = FALSE), error = function(e) e))
+plosdat <- system.file("examples", "plos_data.json", package = "elastic")
+invisible(docs_bulk(plosdat))
 
 test_that("mlt basic", {
-  skip_on_cran()
 
   mlt1 <- mlt(index = "plos", type = "article", id = 5)$hits$total
   mlt2 <- mlt(index = "plos", type = "article", id = 5, min_doc_freq = 12)$hits$total
@@ -28,7 +24,6 @@ test_that("mlt basic", {
 })
 
 test_that("Return different number of results", {
-  skip_on_cran()
 
   mlt4 <- mlt(index = "plos", type = "article", id = 800, search_size = 1)$hits
   mlt5 <- mlt(index = "plos", type = "article", id = 800, search_size = 2)$hits
@@ -44,7 +39,6 @@ test_that("Return different number of results", {
 })
 
 test_that("Exclude stop words", {
-  skip_on_cran()
 
   mlt6 <- mlt(index = "plos", type = "article", id = 800)$hits
   mlt7 <- mlt(index = "plos", type = "article", id = 800, stop_words = "the,and")$hits
@@ -56,7 +50,6 @@ test_that("Exclude stop words", {
 })
 
 test_that("Maximum query terms to be included in the generated query", {
-  skip_on_cran()
 
   mlt8 <- mlt(index = "plos", type = "article", id = 800, max_query_terms = 1)$hits$total
   mlt9 <- mlt(index = "plos", type = "article", id = 800, max_query_terms = 2)$hits$total
@@ -72,6 +65,4 @@ test_that("Maximum query terms to be included in the generated query", {
 })
 
 # cleanup -----------
-if (!is(tryconnect, "simpleError")) {
-  invisible(index_delete("plos", verbose = FALSE))
-}
+invisible(index_delete("plos", verbose = FALSE))
