@@ -1,16 +1,16 @@
 context("docs_bulk")
 
-invisible(connect())
+x <- connect()
 
 test_that("docs_bulk - works with bulk format file", {
   # remove index if it exists
-  if (index_exists("gbifnewgeo")) {
-    index_delete("gbifnewgeo")
+  if (index_exists(x, "gbifnewgeo")) {
+    index_delete(x, "gbifnewgeo")
   }
   # file
   gsmall <- system.file("examples", "gbif_geo.json", package = "elastic")
   # load bulk
-  a <- docs_bulk(x = gsmall, quiet = TRUE)
+  a <- docs_bulk(x, x = gsmall, quiet = TRUE)
   
   expect_is(a, "list")
   expect_named(a, c('took', 'errors', 'items'))
@@ -20,19 +20,19 @@ test_that("docs_bulk - works with bulk format file", {
 
 test_that("docs_bulk - works with data.frame input", {
   # remove index if it exists
-  if (index_exists("hello")) {
-    index_delete("hello")
+  if (index_exists(x, "hello")) {
+    index_delete(x, "hello")
   }
   # load bulk
   iris <- stats::setNames(iris, gsub("\\.", "_", names(iris)))
-  a <- docs_bulk(iris[3:NROW(iris),], index = "hello", type = "world", 
+  a <- docs_bulk(x, iris[3:NROW(iris),], index = "hello", type = "world", 
     quiet = TRUE)
   
   expect_is(a, "list")
   expect_equal(length(a), 1)
   expect_named(a[[1]], c('took', 'errors', 'items'))
   expect_equal(length(a[[1]]$items), NROW(iris[3:NROW(iris),]))
-  if (gsub("\\.", "", ping()$version$number) >= 500) {
+  if (gsub("\\.", "", x$ping()$version$number) >= 500) {
     expect_equal(a[[1]]$items[[1]]$index$`_index`, "hello")
   } else {
     expect_equal(a[[1]]$items[[1]]$create$`_index`, "hello")
@@ -41,13 +41,13 @@ test_that("docs_bulk - works with data.frame input", {
 
 test_that("docs_bulk - works with data.frame where ids are factors", {
   # remove index if it exists
-  if (index_exists("hello2")) {
-    index_delete("hello2")
+  if (index_exists(x, "hello2")) {
+    index_delete(x, "hello2")
   }
   
   # load bulk
   df <- data.frame(name = letters[1:3], size = 1:3, id =c("AB", "CD", "EF"))
-  a <- docs_bulk(df, index = "hello2", type = "hello2", quiet = TRUE)
+  a <- docs_bulk(x, df, index = "hello2", type = "hello2", quiet = TRUE)
   
   expect_is(df$id, "factor")
   expect_is(a, "list")
@@ -58,11 +58,11 @@ test_that("docs_bulk - works with data.frame where ids are factors", {
 
 test_that("docs_bulk - works with list input", {
   # remove index if it exists
-  if (index_exists("arrests")) {
-    index_delete("arrests")
+  if (index_exists(x, "arrests")) {
+    index_delete(x, "arrests")
   }
   # load bulk
-  a <- docs_bulk(apply(USArrests, 1, as.list), index = "arrests", 
+  a <- docs_bulk(x, apply(USArrests, 1, as.list), index = "arrests", 
     quiet = TRUE)
   
   expect_is(a, "list")
@@ -70,7 +70,7 @@ test_that("docs_bulk - works with list input", {
   expect_named(a[[1]], c('took', 'errors', 'items'))
   expect_equal(length(a[[1]]$items), 50)
   
-  if (gsub("\\.", "", ping()$version$number) >= 500) {
+  if (gsub("\\.", "", x$ping()$version$number) >= 500) {
     expect_equal(a[[1]]$items[[1]]$index$`_index`, "arrests")
   } else {
     expect_equal(a[[1]]$items[[1]]$create$`_index`, "arrests")
@@ -79,15 +79,15 @@ test_that("docs_bulk - works with list input", {
 
 test_that("docs_bulk - works with list where ids are factors", {
   # remove index if it exists
-  if (index_exists("hello3")) {
-    index_delete("hello3")
+  if (index_exists(x, "hello3")) {
+    index_delete(x, "hello3")
   }
   
   # load bulk
   df <- data.frame(name = letters[1:3], size = 1:3, id =c("AB", "CD", "EF"))
   lst <- apply(df, 1, as.list)
   lst <- lapply(lst, function(z) {z$id <- as.factor(z$id); z})
-  a <- docs_bulk(lst, index = "hello3", type = "hello3", quiet = TRUE)
+  a <- docs_bulk(x, lst, index = "hello3", type = "hello3", quiet = TRUE)
   
   expect_equal(unique(vapply(lst, function(z) class(z$id), character(1))), "factor")
   expect_is(a, "list")
@@ -100,15 +100,15 @@ test_that("docs_bulk - works with list where ids are factors", {
 
 test_that("docs_bulk fails as expected", {
   # certain classes not supported
-  expect_error(docs_bulk(5, quiet = TRUE), 
+  expect_error(docs_bulk(x, 5, quiet = TRUE), 
     "no 'docs_bulk' method for class numeric")
-  expect_error(docs_bulk(matrix(1), quiet = TRUE), 
+  expect_error(docs_bulk(x, matrix(1), quiet = TRUE), 
     "no 'docs_bulk' method for class matrix")
-  expect_error(docs_bulk(TRUE, quiet = TRUE), 
+  expect_error(docs_bulk(x, TRUE, quiet = TRUE), 
     "no 'docs_bulk' method for class logical")
   
   # character string has to be a file that exists on disk
-  expect_error(docs_bulk("adfadf", quiet = TRUE), 
+  expect_error(docs_bulk(x, "adfadf", quiet = TRUE), 
     "file.exists\\(x\\) is not TRUE")
 })
 
@@ -116,8 +116,8 @@ test_that("docs_bulk fails as expected", {
 test_that("dataset with NA's", {
   # data.frame
   # remove index if it exists
-  if (index_exists("mtcars")) {
-    index_delete("mtcars")
+  if (index_exists(x, "mtcars")) {
+    index_delete(x, "mtcars")
   }
   test1 <- mtcars
   row.names(test1) <- NULL
@@ -126,20 +126,20 @@ test_that("dataset with NA's", {
     x[n] <- NA
     x
   })
-  res <- invisible(docs_bulk(test1, "mtcars", "mtcars", quiet = TRUE))
+  res <- invisible(docs_bulk(x, test1, "mtcars", "mtcars", quiet = TRUE))
   
   expect_is(res, "list")
   expect_is(res[[1]]$items[[1]], "list")
   
   Sys.sleep(2)
-  out <- Search("mtcars", asdf = TRUE)$hits$hits
+  out <- Search(x, "mtcars", asdf = TRUE)$hits$hits
   expect_is(out, "data.frame")
   expect_true(any(is.na(out)))
   
   # list
   # remove index if it exists
-  if (index_exists("mtcars")) {
-    index_delete("mtcars")
+  if (index_exists(x, "mtcars")) {
+    index_delete(x, "mtcars")
   }
   test2 <- mtcars
   row.names(test2) <- NULL
@@ -149,20 +149,20 @@ test_that("dataset with NA's", {
     x
   })
   mtcarslist <- apply(test2, 1, as.list)
-  res <- invisible(docs_bulk(mtcarslist, "mtcars", "mtcars", quiet = TRUE))
+  res <- invisible(docs_bulk(x, mtcarslist, "mtcars", "mtcars", quiet = TRUE))
   
   expect_is(res, "list")
   expect_is(res[[1]]$items[[1]], "list")
   
   Sys.sleep(2)
-  out <- Search("mtcars", asdf = TRUE)$hits$hits
+  out <- Search(x, "mtcars", asdf = TRUE)$hits$hits
   expect_is(out, "data.frame")
   expect_true(any(is.na(out)))
   
   # file
   # remove index if it exists
-  if (index_exists("mtcars")) {
-    index_delete("mtcars")
+  if (index_exists(x, "mtcars")) {
+    index_delete(x, "mtcars")
   }
   test3 <- mtcars
   row.names(test3) <- NULL
@@ -173,13 +173,13 @@ test_that("dataset with NA's", {
   })
   tfile <- tempfile(pattern = "mtcars_file", fileext = ".json")
   res <- invisible(docs_bulk_prep(test3, "mtcars", path = tfile, quiet = TRUE))
-  res <- invisible(docs_bulk(res, quiet = TRUE))
+  res <- invisible(docs_bulk(x, res, quiet = TRUE))
   
   expect_is(res, "list")
   expect_is(res$items[[1]], "list")
   
   Sys.sleep(2)
-  out <- Search("mtcars", asdf = TRUE)$hits$hits
+  out <- Search(x, "mtcars", asdf = TRUE)$hits$hits
   expect_is(out, "data.frame")
   expect_true(any(is.na(out)))
 })
@@ -187,10 +187,10 @@ test_that("dataset with NA's", {
 
 test_that("docs_bulk cleans up temp files", {
   curr_tempdir <- tempdir()
-  if (index_exists("iris")) {
-    index_delete("iris")
+  if (index_exists(x, "iris")) {
+    index_delete(x, "iris")
   }
-  aa <- docs_bulk(apply(iris, 1, as.list), index="iris", type="flowers", 
+  aa <- docs_bulk(x, apply(iris, 1, as.list), index="iris", type="flowers", 
     quiet = TRUE)
 
   expect_equal(length(list.files(curr_tempdir, pattern = "elastic__")), 0)
@@ -199,15 +199,15 @@ test_that("docs_bulk cleans up temp files", {
 
 
 test_that("docs_bulk: suppressing progress bar works", {
-  if (index_exists("asdfdafasdf")) {
-    index_delete("asdfdafasdf")
+  if (index_exists(x, "asdfdafasdf")) {
+    index_delete(x, "asdfdafasdf")
   }
 
   quiet_true <- capture.output(invisible(
-    docs_bulk(mtcars, index="asdfdafasdf", type="asdfadfsdfsdfdf", 
+    docs_bulk(x, mtcars, index="asdfdafasdf", type="asdfadfsdfsdfdf", 
       quiet = TRUE)))
   quiet_false <- capture.output(invisible(
-    docs_bulk(mtcars, index="asdfdafasdf", type="asdfadfsdfsdfdf", 
+    docs_bulk(x, mtcars, index="asdfdafasdf", type="asdfadfsdfsdfdf", 
       quiet = FALSE)))
   expect_equal(length(quiet_true), 0)
   expect_match(quiet_false, "=====")
