@@ -1,32 +1,33 @@
 context("explain")
 
-invisible(connect())
+x <- connect()
+load_shakespeare(x)
 
 test_that("explain", {
-  type_ <- if (es_ver() < 600) "scene" else "line"
+  type_ <- if (x$es_ver() < 600) "scene" else "line"
 
-  a <- explain(index = "shakespeare", type = type_, id = 324, q = "palace")
+  a <- explain(x, index = "shakespeare", type = type_, id = 324, q = "palace")
 
   body <- '{
    "query": {
      "term": { "text_entry": "palace" }
    }
   }'
-  b <- explain(index = "shakespeare", type = type_, id = 324, body = body)
+  b <- explain(x, index = "shakespeare", type = type_, id = 324, body = body)
 
   body <- '{
    "query": {
      "term": { "text_entry": "stuff" }
    }
   }'
-  c <- explain(index = "shakespeare", type = type_, id = 324, body = body)
+  c <- explain(x, index = "shakespeare", type = type_, id = 324, body = body)
 
   expect_is(a, "list")
   expect_is(b, "list")
   expect_is(c, "list")
 
-  if (es_ver() < 600) {
-    if (es_ver() >= 200) {
+  if (x$es_ver() < 600) {
+    if (x$es_ver() >= 200) {
       expect_match(a$explanation$description, "sum of")
       expect_match(b$explanation$description, "sum of")
       expect_match(c$explanation$description, "Failure to meet condition")  
