@@ -1,24 +1,29 @@
 context("msearch")
 
-invisible(connect())
+x <- connect()
+load_shakespeare(x)
 
 test_that("basic multi-search works", {
-
-  cat('{"index" : "shakespeare"}', file = "~/mysearch.json", sep = "\n")
+  tf <- tempfile(fileext = ".json")
+  cat('{"index" : "shakespeare"}', file = tf, sep = "\n")
   cat('{"query" : {"match_all" : {}}, "from" : 0, "size" : 5}',  sep = "\n",
-      file = "~/mysearch.json", append = TRUE)
-  aa <- msearch("~/mysearch.json")
+      file = tf, append = TRUE)
+  aa <- msearch(x, tf)
 
   expect_is(aa, "list")
-  expect_equal(length(aa), 1)
+  if (es_version(x) >= 700) {
+    expect_named(aa, c('took', 'responses'))
+  } else {
+    expect_named(aa, 'responses')
+  }
   expect_equal(length(aa$responses), 1)
   expect_is(aa$responses, "list")
 
   msearch1 <- system.file("examples", "msearch_eg1.json", package = "elastic")
-  bb <- msearch(msearch1)
+  bb <- msearch(x, msearch1)
 
   msearch2 <- system.file("examples", "msearch_eg2.json", package = "elastic")
-  cc <- msearch(msearch2)
+  cc <- msearch(x, msearch2)
 
   expect_is(bb, "list")
   expect_equal(length(bb$responses), 1)
@@ -33,17 +38,22 @@ test_that("multi-search fails well", {
   ff <- tempfile(fileext = ".json")
   cat('{"query" : {"match_all" : {}}, "from" : 0, "size" : 5}',  sep = "\n",
       file = ff, append = TRUE)
-  expect_error(msearch(ff), "Validation Failed")
+  if (es_version(x) >= 700) {
+    expect_error(msearch(x, ff), "not supported")
+  } else {
+    expect_error(msearch(x, ff), "Validation Failed")
+  }
 
   ### same, but complete errors
-  invisible(connect(errors = "complete"))
-  expect_error(msearch(ff), "action_request_validation_exception||ActionRequestValidationException")
+  x <- connect(errors = "complete")
+  expect_error(msearch(x, ff), 
+    "action_request_validation_exception||ActionRequestValidationException")
 
   ## same as above
   ff <- tempfile(fileext = ".json")
   cat('{}',  sep = "\n", file = ff, append = TRUE)
-  expect_error(msearch(ff), "Validation Failed")
+  expect_error(msearch(x, ff), "Validation Failed")
 
   ## file does not exist
-  expect_error(msearch("asdf"), "file asdf does not exist")
+  expect_error(msearch(x, "asdf"), "file asdf does not exist")
 })
