@@ -1,13 +1,9 @@
 context("mtermvectors")
 
-invisible(connect())
+x <- connect()
+load_omdb(x)
 
-if (!index_exists('omdb')) {
-  omdb <- system.file("examples", "omdb.json", package = "elastic")
-  invisible(docs_bulk(omdb))
-}
-
-ids <- vapply(Search("omdb", size = 2)$hits$hits, "[[", "", "_id")
+ids <- vapply(Search(x, "omdb", size = 2)$hits$hits, "[[", "", "_id")
 body <- sprintf('{
        "ids" : ["%s", "%s"],
        "parameters": {
@@ -20,9 +16,9 @@ body <- sprintf('{
 
 test_that("mtermvectors works", {
   skip_on_travis()
-  if (gsub("\\.", "", ping()$version$number) < 130) skip('feature not in this ES version')
+  if (gsub("\\.", "", x$ping()$version$number) < 130) skip('feature not in this ES version')
 
-  aa <- mtermvectors('omdb', 'omdb', body = body)
+  aa <- mtermvectors(x, 'omdb', 'omdb', body = body)
 
   expect_is(aa, 'list')
   expect_named(aa, 'docs')
@@ -43,6 +39,9 @@ test_that("mtermvectors works", {
 test_that("mtermvectors fails well", {
   skip_on_travis()
 
-  expect_error(mtermvectors(body = body), "index is missing")
-  expect_error(mtermvectors("omdb", body = body), "type is missing")
+  expect_error(mtermvectors(x, body = body), "index is missing")
+
+  if (es_version(x) < 700) {
+    expect_error(mtermvectors(x, "omdb", body = body), "type is missing")
+  }
 })
